//   Copyright 2012 Georg-August-Universität Göttingen, Germany
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package de.ugoe.cs.autoquest.usability.rules;

import com.google.common.base.Optional;

import de.ugoe.cs.autoquest.usability.result.UsabilityProblemDescription;

/**
 * <p>
 * Interface for usability metrics. A metric is a way of measuring or evaluating a particular
 * phenomenon or thing, in this case usability.
 * </p>
 * 
 * @author Alexander Deicke
 */
public interface UsabilityMetric {

    /**
     * 
     * <p>
     * Calculates the metric.
     * </p>
     * 
     * @return Detailed description of the usability problem, if calculated metric exceeds defined
     *         threshold.
     */
    public Optional<UsabilityProblemDescription> calculate();

}
